<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:user="http://mycompany.com/mynamespace" xmlns:fo="http://www.w3.org/1999/XSL/Format"  xmlns:XmlReporting="urn:XmlReporting">
  <msxsl:script language="Javascript"  implements-prefix="user">
    <![CDATA[

		function formatPercentage(number, total)
		{
			if (total == 0)
			{
				return "0.00%";
			}
			
			return (100 * number / total).toFixed(2) + "%";
		}
		
		function getDirectory(filename)
		{
			var index = filename.lastIndexOf("\\");
			
			if (index == -1)
			{
				return "";
			}
			else
			{
				return filename.substr(0, index + 1);
			}
		}
		
		function getCharsPerWord(words, chars)
		{
			return (chars / words).toFixed(2);
		}	
		]]>
  </msxsl:script>
  <xsl:key name="directory" match="file" use="user:getDirectory(string(@name))"/>
  <xsl:template match="/">
    <html>
      <head>
        <xsl:value-of select="XmlReporting:GetDefaultCssLinkTag()" disable-output-escaping="yes"/>
        <script language="JavaScript">
          <![CDATA[
					
						function OpenFile(guid)
						{
							if (window.external)
							{
								try
								{
									window.external.OpenFile(guid); 
								}
								catch (e)
								{
									document.getElementById(guid).click();
								}
							}
							else
							{
								document.getElementById(guid).click();
							}
						}

						function Switch(fileguid, showhide)
						{
							if (showhide == "hide")
							{
								document.getElementById(fileguid + "_plus").style.display="";
								document.getElementById(fileguid + "_minus").style.display="none";							
								document.getElementById(fileguid + "_files").style.display="none";
							}
							else
							{
								document.getElementById(fileguid + "_plus").style.display="none";
								document.getElementById(fileguid + "_minus").style.display="";							
								document.getElementById(fileguid + "_files").style.display="";
							}
						}
						
					]]>
        </script>
      </head>
      <body>
        <table  width="100%" border="0" cellpadding="0" cellspacing="0">
          <tr>
            <td width="100%">
              <h1>
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Title')" />
              </h1>
            </td>
            <td valign="top">
              <img>
                <xsl:attribute name="src">
                  <xsl:value-of select="XmlReporting:GetImagesUrl()"/>/StudioPower.jpg
                </xsl:attribute>
              </img>
            </td>
          </tr>
        </table>

        <h2 class="first">
          <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Summary')" />
        </h2>

        <table class="InfoList" width="100%" border="0" cellpadding="0" cellspacing="2">

          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Task')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Name')" />
            </td>
          </tr>

          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Project')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/project/@name"/>
            </td>
          </tr>

          <xsl:if test="//customer/@name">
            <tr>
              <td class="InfoItem">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Customer')" />
              </td>
              <td class="InfoData">
                <xsl:value-of select="//taskInfo/customer/@name"/>
                <xsl:if test="//customer/@email">
                  &#32;(<xsl:value-of select="//taskInfo/customer/@email"/>)
                </xsl:if>
              </td>
            </tr>
          </xsl:if>

          <xsl:if test="//project/@dueDate">
            <tr>
              <td class="InfoItem">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_DueDate')" />
              </td>
              <td class="InfoData">
                <xsl:value-of select="//taskInfo/project/@dueDate"/>
              </td>
            </tr>
          </xsl:if>

          <xsl:for-each select="//taskInfo/tm">
            <xsl:choose>
              <xsl:when test="position()=1">
                <tr>
                  <td class="InfoItem">
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_TMs')" />
                  </td>
                  <td class="InfoData">
                    <xsl:value-of select="@name"/>
                  </td>
                </tr>
              </xsl:when>
              <xsl:otherwise>
                <tr>
                  <td class="InfoItem" />
                  <td class="InfoData">
                    <xsl:value-of select="@name"/>
                  </td>
                </tr>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:for-each>

          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Language')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/language/@name"/>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Files')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="count(task/file)"/>
            </td>
          </tr>

          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_CreatedAt')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/@runAt"/>
            </td>
          </tr>

          <xsl:if test="//taskInfo/@runTime">
            <tr>
              <td class="InfoItem">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_RunTime')" />
              </td>
              <td class="InfoData">
                <xsl:value-of select="//taskInfo/@runTime"/>
              </td>
            </tr>
          </xsl:if>


        </table>

        <h2 class="first">
          <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Settings')" />
        </h2>

        <table class="InfoList" width="100%" border="0" cellpadding="0" cellspacing="2">
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_MinimumMatchScore')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/settings/@minimumMatchScore"/>
              <xsl:text>%</xsl:text>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_TranslationOverwriteMode')" />
            </td>
            <td class="InfoData">
              <xsl:if test="//taskInfo/settings/@translationOverwriteMode='keepExisting'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_TranslationOverwriteMode_Keep')" />
              </xsl:if>
              <xsl:if test="//taskInfo/settings/@translationOverwriteMode='alwaysOverwrite'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_TranslationOverwriteMode_Always')" />
              </xsl:if>
              <xsl:if test="//taskInfo/settings/@translationOverwriteMode='overwriteOnlyIfBetter'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_TranslationOverwriteMode_OnlyIfBetter')" />
              </xsl:if>
            </td>
          </tr>

          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_SearchMode')" />
            </td>
            <td class="InfoData">
              <xsl:if test="//taskInfo/settings/@searchMode='bestWins'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_SearchMode_BestWins')" />
              </xsl:if>
              <xsl:if test="//taskInfo/settings/@searchMode='firstWins'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_SearchMode_FirstWins')" />
              </xsl:if>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_MissingFormattingPenalty')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/settings/@missingFormattingPenalty"/>
              <xsl:text>%</xsl:text>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_DifferentFormattingPenalty')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/settings/@differentFormattingPenalty"/>
              <xsl:text>%</xsl:text>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_MultipleTranslationsPenalty')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/settings/@multipleTranslationsPenalty"/>
              <xsl:text>%</xsl:text>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_AutoLocalizationPenalty')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/settings/@autoLocalizationPenalty"/>
              <xsl:text>%</xsl:text>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_TextReplacementPenalty')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/settings/@textReplacementPenalty"/>
              <xsl:text>%</xsl:text>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_AlignmentPenalty')" />
            </td>
            <td class="InfoData">
              <xsl:value-of select="//taskInfo/settings/@alignmentPenalty"/>
              <xsl:text>%</xsl:text>
            </td>
            <td class="InfoData">
              <xsl:text>&#160;</xsl:text>
            </td>
          </tr>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_CharacterWidthDifferencePenalty')" />
            </td>
            <td class="InfoData">
              <xsl:choose>
                <xsl:when test="//taskInfo/settings/@characterWidthDifferencePenaltyEnabled='yes'">
                  <xsl:value-of select="//taskInfo/settings/@characterWidthDifferencePenalty"/>
                  <xsl:text>%</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_CharacterWidthDifferencePenaltyNoMatch')" />
                </xsl:otherwise>
              </xsl:choose>
            </td>
            <td class="InfoData">
              <xsl:text>&#160;</xsl:text>
            </td>
          </tr>
          <xsl:if test="//taskInfo/settings/@icuTokenization">
            <tr>
              <td class="InfoItem">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_IcuTokenization')" />
              </td>
              <td class="InfoData">
                <xsl:choose>
                  <xsl:when test="//taskInfo/settings/@icuTokenization='True'">
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
                  </xsl:otherwise>
                </xsl:choose>
              </td>
            </tr>
          </xsl:if>
          <tr>
            <td class="InfoItem">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_AfterApplyingTranslations')" />
            </td>
          </tr>
          <tr>
            <td class="InfoItemWithIndent">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Confirm100Matches')" />
            </td>
            <td class="InfoData">
              <xsl:if test="//taskInfo/settings/@confirm100Matches='yes'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
              </xsl:if>
              <xsl:if test="//taskInfo/settings/@confirm100Matches='no'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
              </xsl:if>
            </td>
          </tr>
          <xsl:if test="//taskInfo/settings/@lock100Matches">
            <tr>
              <td class="InfoItemWithIndent">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Lock100Matches')" />
              </td>
              <td class="InfoData">
                <xsl:if test="//taskInfo/settings/@lock100Matches='yes'">
                  <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
                </xsl:if>
                <xsl:if test="//taskInfo/settings/@lock100Matches='no'">
                  <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
                </xsl:if>
              </td>
            </tr>
          </xsl:if>
          <tr>
            <td class="InfoItemWithIndent">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_ConfirmContextMatches')" />
            </td>
            <td class="InfoData">
              <xsl:if test="//taskInfo/settings/@confirmContextMatches='yes'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
              </xsl:if>
              <xsl:if test="//taskInfo/settings/@confirmContextMatches='no'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
              </xsl:if>
            </td>
          </tr>
          <tr>
            <td class="InfoItemWithIndent">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_LockContextMatches')" />
            </td>
            <td class="InfoData">
              <xsl:if test="//taskInfo/settings/@lockContextMatches='yes'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
              </xsl:if>
              <xsl:if test="//taskInfo/settings/@lockContextMatches='no'">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
              </xsl:if>
            </td>
          </tr>


          <xsl:if test="//taskInfo/settings/@enableFuzzyMatchRepair">
            <tr>
              <td class="InfoItem">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_EnableFuzzyMatchRepair')" />
              </td>
              <td class="InfoData">
                <xsl:choose>
                  <xsl:when test="//taskInfo/settings/@enableFuzzyMatchRepair='yes'">
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
                  </xsl:otherwise>
                </xsl:choose>
              </td>
              <td class="InfoData">
                <xsl:text>&#160;</xsl:text>
              </td>
            </tr>

            <tr>
              <td class="InfoItemWithIndent">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_EnableMtFuzzyMatchRepair')" />
              </td>
              <td class="InfoData">
                <xsl:choose>
                  <xsl:when test="//taskInfo/settings/@enableMtFuzzyMatchRepair='yes'">
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
                  </xsl:otherwise>
                </xsl:choose>
              </td>
              <td class="InfoData">
                <xsl:text>&#160;</xsl:text>
              </td>
            </tr>

            <tr>
              <td class="InfoItemWithIndent">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_EnableTermbasesFuzzyMatchRepair')" />
              </td>
              <td class="InfoData">
                <xsl:choose>
                  <xsl:when test="//taskInfo/settings/@enableTermbasesFuzzyMatchRepair='yes'">
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Yes')" />
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_No')" />
                  </xsl:otherwise>
                </xsl:choose>
              </td>
              <td class="InfoData">
                <xsl:text>&#160;</xsl:text>
              </td>
            </tr>

          </xsl:if>

        </table>


        <h2>
          <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Totals')" />
        </h2>
        <table class="ReportTable" border="0" cellspacing="0" cellpadding="2" width="100%">
          <tr>
            <th class="TypeHead" width="100%">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Total')" />
            </th>
            <th class="TypeHead">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Type')" />
            </th>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Segments')" />
            </th>
            <xsl:if test="//total/@words">
              <th class="Unit">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Words')" />
              </th>
            </xsl:if>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Characters')" />
            </th>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Percent')" />
            </th>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Placeables')" />
            </th>
            <xsl:if test="//taskInfo/settings/@enableFuzzyMatchRepair">
              <th class="Unit">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_RepairedWords')" />
              </th>
            </xsl:if>
            <xsl:if test="//total/@tags">
              <th class="Unit">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Tags')" />
              </th>
            </xsl:if>
          </tr>
          <xsl:apply-templates select="//batchTotal"/>
        </table>

        <h2>
          <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_FileDetails')" />
        </h2>

        <table class="ReportTable" border="0" cellspacing="0" cellpadding="2"  width="100%">
          <tr>
            <th class="TypeHead" width="100%">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_File')" />
            </th>
            <th class="TypeHead">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Type')" />
            </th>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Segments')" />
            </th>
            <xsl:if test="//total/@words">
              <th class="Unit">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Words')" />
              </th>
            </xsl:if>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Characters')" />
            </th>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Percent')" />
            </th>
            <th class="Unit">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Placeables')" />
            </th>
            <xsl:if test="//taskInfo/settings/@enableFuzzyMatchRepair">
              <th class="Unit">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_RepairedWords')" />
              </th>
            </xsl:if>
            <xsl:if test="//total/@tags">
              <th class="Unit">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Tags')" />
              </th>
            </xsl:if>
          </tr>

          <xsl:for-each select="//file[generate-id() = generate-id(key('directory', user:getDirectory(string(@name)))[1])]">
            <xsl:sort select="user:getDirectory(string(@name))"/>
            <xsl:call-template name="folder">
              <xsl:with-param name="currentFolder" select="user:getDirectory(string(@name))" />
            </xsl:call-template>
          </xsl:for-each>

        </table>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="folder">
    <xsl:param name="currentFolder"/>
    <xsl:if test="local-name() = 'file'">
      <xsl:apply-templates select="//file[starts-with(@name, $currentFolder) and not(contains(substring-after(@name, $currentFolder), '\'))]">
        <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
    <xsl:if test="local-name() = 'mergedFile'">
      <xsl:apply-templates select="//mergedFile[starts-with(@name, $currentFolder) and not(contains(substring-after(@name, $currentFolder), '\'))]">
        <xsl:sort select="@name"/>
      </xsl:apply-templates>
    </xsl:if>
  </xsl:template>

  <xsl:template name="counts" match="copySource | inserted | unchanged | updated">
    <td>
      <xsl:value-of select="@segments"/>
    </td>

    <xsl:choose>
      <xsl:when test="//total/@words">
        <td>
          <xsl:value-of select="@words" />
        </td>
        <td>
          <xsl:value-of select="@characters" />
        </td>
        <td>
          <xsl:value-of select="user:formatPercentage(number(@words), number(../total/@words))"/>
        </td>
      </xsl:when>
      <xsl:otherwise>
        <td>
          <xsl:value-of select="@characters" />
        </td>
        <td>
          <xsl:value-of select="user:formatPercentage(number(@characters), number(../total/@characters))"/>
        </td>
      </xsl:otherwise>
    </xsl:choose>
    <td>
      <xsl:value-of select="@placeables"/>
    </td>
    <xsl:if test="//taskInfo/settings/@enableFuzzyMatchRepair">
      <td>
        <xsl:value-of select="@repairWords"/>
      </td>
    </xsl:if>
    <xsl:if test="@tags">
      <td>
        <xsl:value-of select="@tags"/>
      </td>
    </xsl:if>
  </xsl:template>
  <xsl:template match="file | batchTotal">

    <xsl:if test="local-name() = 'file'">
      <xsl:choose>
        <xsl:when test="mergedFiles">
          <tbody>
            <xsl:attribute name="id">
              <xsl:value-of select="@guid"/>
              <xsl:text>_plus</xsl:text>
            </xsl:attribute>
            <tr>
              <th class="File" align="left" valign="top">
                <img>
                  <xsl:attribute name="onclick">
                    Switch('<xsl:value-of select="@guid"/>','show');
                  </xsl:attribute>
                  <xsl:attribute name="src">
                    <xsl:value-of select="XmlReporting:GetImagesUrl()"/>/plus.gif
                  </xsl:attribute>
                </img>
                <xsl:text>&#32;</xsl:text>
                <a>
                  <xsl:attribute name="href">
                    javascript:OpenFile('<xsl:value-of select="@guid"/>')
                  </xsl:attribute>
                  <xsl:value-of select="@name"/>
                </a>
                <xsl:text>&#32;(</xsl:text>
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_MergedFiles')" />
                <xsl:value-of select="count(mergedFiles/mergedFile)"/>
                <xsl:text>)</xsl:text>
              </th>
              <th class="Header">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Translated')" />
              </th>
              <xsl:apply-templates select="translate/inserted"/>
            </tr>
          </tbody>

          <tbody style='display: none;'>
            <xsl:attribute name="id">
              <xsl:value-of select="@guid"/>
              <xsl:text>_minus</xsl:text>
            </xsl:attribute>
            <tr>
              <th class="File" align="left" valign="top">
                <img>
                  <xsl:attribute name="onclick">
                    Switch('<xsl:value-of select="@guid"/>','hide');
                  </xsl:attribute>
                  <xsl:attribute name="src">
                    <xsl:value-of select="XmlReporting:GetImagesUrl()"/>/minus.gif
                  </xsl:attribute>
                </img>
                <xsl:text>&#32;</xsl:text>
                <a>
                  <xsl:attribute name="href">
                    javascript:OpenFile('<xsl:value-of select="@guid"/>')
                  </xsl:attribute>
                  <xsl:value-of select="@name"/>
                </a>
                <xsl:text>&#32;(</xsl:text>
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_MergedFiles')" />
                <xsl:value-of select="count(mergedFiles/mergedFile)"/>
                <xsl:text>)</xsl:text>
              </th>
              <th class="Header">
                <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Translated')" />
              </th>
              <xsl:apply-templates select="translate/inserted"/>
            </tr>
          </tbody>
        </xsl:when>

        <xsl:otherwise>
          <tr>
            <th class="File" align="left" valign="top">
              <xsl:value-of select="@name"/>
            </th>
            <th class="Header">
              <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Translated')" />
            </th>
            <xsl:apply-templates select="translate/inserted"/>
          </tr>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>

    <xsl:if test="local-name() = 'batchTotal'">

      <tr>
        <th class="File" align="left" valign="top">
          <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Files')" />&#32;
          <xsl:value-of select="count(parent::node()/file)"/>
        </th>
        <th class="Header">
          <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Translated')" />
        </th>
        <xsl:apply-templates select="translate/inserted"/>

      </tr>

    </xsl:if>


    <tr>
      <th class="CharPerWord" rowspan="4" align="left" valign="top">
        &#32;
      </th>
      <th class="Header">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Updated')" />
      </th>
      <xsl:apply-templates select="translate/updated"/>
    </tr>
    <tr>
      <th class="Header">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_CopySource')" />
      </th>
      <xsl:apply-templates select="translate/copySource"/>
    </tr>
    <tr>
      <th class="Header">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Unchanged')" />
      </th>
      <xsl:apply-templates select="translate/unchanged"/>
    </tr>

    <tr>
      <th class="Total">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Total')" />
      </th>
      <td class="Total">
        <xsl:value-of select="translate/total/@segments"/>
      </td>
      <xsl:if test="translate/total/@words">
        <td class="Total">
          <xsl:value-of select="translate/total/@words"/>
        </td>
      </xsl:if>
      <td class="Total">
        <xsl:value-of select="translate/total/@characters"/>
      </td>
      <td class="Total">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Exact')" />
      </td>
      <td class="Total">
        <xsl:value-of select="translate/total/@placeables"/>
      </td>
      <xsl:if test="//taskInfo/settings/@enableFuzzyMatchRepair">
        <td class="Total">
          <xsl:value-of select="translate/total/@repairWords"/>
        </td>
      </xsl:if>
      <xsl:if test="translate/total/@tags">
        <td class="Total">
          <xsl:value-of select="translate/total/@tags"/>
        </td>
      </xsl:if>
    </tr>

    <xsl:if test="mergedFiles">

      <tbody style='display: none;'>
        <xsl:attribute name="id">
          <xsl:value-of select="@guid"/>
          <xsl:text>_files</xsl:text>
        </xsl:attribute>

        <xsl:for-each select="mergedFiles/mergedFile">
          <xsl:sort select="@name"/>
          <xsl:call-template name="mergedFile"></xsl:call-template>
        </xsl:for-each>

      </tbody>

    </xsl:if>

  </xsl:template>
  <xsl:template name="mergedFile">
    <tr>
      <th class="MergedFile" rowspan="5" align="left" valign="top">
        <xsl:value-of select="@name"/>
      </th>
      <th class="MergedHeader">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Translated')" />
      </th>
      <xsl:apply-templates select="translate/inserted"/>
    </tr>
    <tr>
      <th class="MergedHeader">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Updated')" />
      </th>
      <xsl:apply-templates select="translate/updated"/>
    </tr>
    <tr>
      <th class="MergedHeader">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_CopySource')" />
      </th>
      <xsl:apply-templates select="translate/copySource"/>
    </tr>
    <tr>
      <th class="MergedHeader">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Unchanged')" />
      </th>
      <xsl:apply-templates select="translate/unchanged"/>
    </tr>

    <tr>
      <th class="Total">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Total')" />
      </th>
      <td class="Total">
        <xsl:value-of select="translate/total/@segments"/>
      </td>
      <xsl:if test="translate/total/@words">
        <td class="Total">
          <xsl:value-of select="translate/total/@words"/>
        </td>
      </xsl:if>
      <td class="Total">
        <xsl:value-of select="translate/total/@characters"/>
      </td>
      <td class="Total">
        <xsl:value-of select="XmlReporting:GetResourceString('TranslateReport_Exact')" />
      </td>
      <td class="Total">
        <xsl:value-of select="translate/total/@placeables"/>
      </td>
      <xsl:if test="//taskInfo/settings/@enableFuzzyMatchRepair">
        <td class="Total">
          <xsl:value-of select="translate/total/@repairWords"/>
        </td>
      </xsl:if>
      <xsl:if test="translate/total/@tags">
        <td class="Total">
          <xsl:value-of select="translate/total/@tags"/>
        </td>
      </xsl:if>
    </tr>

  </xsl:template>
</xsl:stylesheet>
